@@ -10,23 +10,15 @@ from nose.plugins.manager import NoPlugins
 from warnings import warn, filterwarnings
 
 log = logging.getLogger(__name__)
-
-# not allowed in config files
-option_blacklist = ['help', 'verbose']
-
+option_blacklist = ['help', 'verbose']  # Not allowed in config files
 config_files = [
-    # Linux users will prefer this
-    "~/.noserc",
-    # Windows users will prefer this
-    "~/nose.cfg"
-    ]
-
-# plaforms on which the exe check defaults to off
-# Windows and IronPython
+    "~/.noserc",  # Linux users will prefer this
+    "~/nose.cfg",  # Windows users will prefer this
+]
 exe_allowed_platforms = ('win32', 'cli')
-
-filterwarnings("always", category=DeprecationWarning,
-               module=r'(.*\.)?nose\.config')
+filterwarnings(
+    "always", category=DeprecationWarning, module=r'(.*\.)?nose\.config'
+)
 
 
 class NoSuchOptionError(Exception):
@@ -65,8 +57,9 @@ class ConfiguredDefaultsOptionParser(object):
             try:
                 cfg.read(filename)
             except configparser.Error as exc:
-                raise ConfigError("Error reading config file %r: %s" %
-                                  (filename, str(exc)))
+                raise ConfigError(
+                    "Error reading config file %r: %s" % (filename, str(exc))
+                )
             config.extend(self._configTuples(cfg, filename))
         return config
 
@@ -139,47 +132,44 @@ class ConfiguredDefaultsOptionParser(object):
 
 class Config(object):
     r"""nose configuration.
-
-    Instances of Config are used throughout nose to configure
-    behavior, including plugin lists. Here are the default values for
-    all config keys::
-
-      self.env = env = kw.pop('env', {})
-      self.args = ()
-      self.testMatch = re.compile(r'(?:^|[\\b_\\.%s-])[Tt]est' % os.sep)
-      self.addPaths = not env.get('NOSE_NOPATH', False)
-      self.configSection = 'nosetests'
-      self.debug = env.get('NOSE_DEBUG')
-      self.debugLog = env.get('NOSE_DEBUG_LOG')
-      self.exclude = None
-      self.getTestCaseNamesCompat = False
-      self.includeExe = env.get('NOSE_INCLUDE_EXE',
-                                sys.platform in exe_allowed_platforms)
-      self.ignoreFiles = (re.compile(r'^\.'),
-                          re.compile(r'^_'),
-                          re.compile(r'^setup\.py$')
-                          )
-      self.include = None
-      self.loggingConfig = None
-      self.logStream = sys.stderr
-      self.options = NoOptions()
-      self.parser = None
-      self.plugins = NoPlugins()
-      self.srcDirs = ('lib', 'src')
-      self.runOnInit = True
-      self.stopOnError = env.get('NOSE_STOP', False)
-      self.stream = sys.stderr
-      self.testNames = ()
-      self.verbosity = int(env.get('NOSE_VERBOSE', 1))
-      self.where = ()
-      self.py3where = ()
-      self.workingDir = None """
-
+    Instances of Config are used throughout nose to configure behavior,
+    including plugin lists. * Here are the default values for all config keys:
+        self.env = env = kw.pop('env', {})
+        self.args = ()
+        self.testMatch = re.compile(r'(?:^|[\\b_\\.%s-])[Tt]est' % os.sep)
+        self.addPaths = not env.get('NOSE_NOPATH', False)
+        self.configSection = 'nosetests'
+        self.debug = env.get('NOSE_DEBUG')
+        self.debugLog = env.get('NOSE_DEBUG_LOG')
+        self.exclude = None
+        self.getTestCaseNamesCompat = False
+        self.includeExe = env.get(
+            'NOSE_INCLUDE_EXE', sys.platform in exe_allowed_platforms
+        )
+        self.ignoreFiles = (
+            re.compile(r'^\.'), re.compile(r'^_'), re.compile(r'^setup\.py$')
+        )
+        self.include = None
+        self.loggingConfig = None
+        self.logStream = sys.stderr
+        self.options = NoOptions()
+        self.parser = None
+        self.plugins = NoPlugins()
+        self.srcDirs = ('lib', 'src')
+        self.runOnInit = True
+        self.stopOnError = env.get('NOSE_STOP', False)
+        self.stream = sys.stderr
+        self.testNames = ()
+        self.verbosity = int(env.get('NOSE_VERBOSE', 1))
+        self.where = ()
+        self.py3where = ()
+        self.workingDir = None """
     def __init__(self, **kw):
         self.env = env = kw.pop('env', {})
         self.args = ()
-        self.testMatchPat = env.get('NOSE_TESTMATCH',
-                                    r'(?:^|[\b_\.%s-])[Tt]est' % os.sep)
+        self.testMatchPat = env.get(
+            'NOSE_TESTMATCH', r'(?:^|[\b_\.%s-])[Tt]est' % os.sep
+        )
         self.testMatch = re.compile(self.testMatchPat)
         self.addPaths = not env.get('NOSE_NOPATH', False)
         self.configSection = 'nosetests'
@@ -187,12 +177,10 @@ class Config(object):
         self.debugLog = env.get('NOSE_DEBUG_LOG')
         self.exclude = None
         self.getTestCaseNamesCompat = False
-        self.includeExe = env.get('NOSE_INCLUDE_EXE',
-                                  sys.platform in exe_allowed_platforms)
-        self.ignoreFilesDefaultStrings = [r'^\.',
-                                          r'^_',
-                                          r'^setup\.py$',
-                                          ]
+        self.includeExe = env.get(
+            'NOSE_INCLUDE_EXE', sys.platform in exe_allowed_platforms
+        )
+        self.ignoreFilesDefaultStrings = [r'^\.', r'^_', r'^setup\.py$']
         self.ignoreFiles = list(
             map(re.compile, self.ignoreFilesDefaultStrings)
         )
@@ -215,7 +203,6 @@ class Config(object):
         self.firstPackageWins = False
         self.parserClass = OptionParser
         self.worker = False
-
         self._default = self.__dict__.copy()
         self.update(kw)
         self._orig = self.__dict__.copy()
@@ -227,7 +214,6 @@ class Config(object):
         del state['_default']
         del state['env']
         del state['logStream']
-        # FIXME remove plugins, have only plugin manager class
         state['plugins'] = self.plugins.__class__
         return state
 
@@ -235,23 +221,19 @@ class Config(object):
         plugincls = state.pop('plugins')
         self.update(state)
         self.worker = True
-        # FIXME won't work for static plugin lists
         self.plugins = plugincls()
         self.plugins.loadPlugins()
-        # needed so .can_configure gets set appropriately
         dummy_parser = self.parserClass()
         self.plugins.addOptions(dummy_parser, {})
         self.plugins.configure(self.options, self)
 
     def __repr__(self):
         d = self.__dict__.copy()
-        #  don't expose env, could include sensitive info
+        # Don't expose env. That could include sensitive info.
         d['env'] = {}
         keys = [k for k in list(d.keys()) if not k.startswith('_')]
         keys.sort()
-        return "Config(%s)" % ', '.join(
-            ['%s=%r' % (k, d[k]) for k in keys]
-        )
+        return "Config(%s)" % ', '.join(['%s=%r' % (k, d[k]) for k in keys])
     __str__ = __repr__
 
     def _parseArgs(self, argv, cfg_files):
@@ -279,37 +261,26 @@ class Config(object):
         env = self.env
         if argv is None:
             argv = sys.argv
-
         cfg_files = getattr(self, 'files', [])
         options, args = self._parseArgs(argv, cfg_files)
-        # If -c --config has been specified on command line,
-        # load those config files and reparse
+        # If -c --config has been specified, then load those configs & reparse.
         if getattr(options, 'files', []):
             options, args = self._parseArgs(argv, options.files)
-
         self.options = options
         if args:
             self.testNames = args
         if options.testNames is not None:
             self.testNames.extend(tolist(options.testNames))
-
         if options.py3where is not None:
-            if sys.version_info >= (3,):
-                options.where = options.py3where
-
-        # `where` is an append action, so it can't have a default value
-        # in the parser, or that default will always be in the list
+            options.where = options.py3where
         if not options.where:
             options.where = env.get('NOSE_WHERE', None)
-
-        # include and exclude also
         if not options.ignoreFiles:
             options.ignoreFiles = env.get('NOSE_IGNORE_FILES', [])
         if not options.include:
             options.include = env.get('NOSE_INCLUDE', [])
         if not options.exclude:
             options.exclude = env.get('NOSE_EXCLUDE', [])
-
         self.addPaths = options.addPaths
         self.stopOnError = options.stopOnError
         self.verbosity = options.verbosity
@@ -320,16 +291,12 @@ class Config(object):
         self.loggingConfig = options.loggingConfig
         self.firstPackageWins = options.firstPackageWins
         self.configureLogging()
-
         if not options.byteCompile:
             sys.dont_write_bytecode = True
-
         if options.where is not None:
             self.configureWhere(options.where)
-
         if options.testMatch:
             self.testMatch = re.compile(options.testMatch)
-
         if options.ignoreFiles:
             self.ignoreFiles = list(
                 map(re.compile, tolist(options.ignoreFiles))
@@ -339,15 +306,12 @@ class Config(object):
             log.info(
                 "Ignoring files matching %s", self.ignoreFilesDefaultStrings
             )
-
         if options.include:
             self.include = list(map(re.compile, tolist(options.include)))
             log.info("Including tests matching %s", options.include)
-
         if options.exclude:
             self.exclude = list(map(re.compile, tolist(options.exclude)))
             log.info("Excluding tests matching %s", options.exclude)
-
         # When listing plugins we don't want to run them
         if not options.showPlugins:
             self.plugins.configure(options, self)
@@ -362,35 +326,32 @@ class Config(object):
             from logging.config import fileConfig
             fileConfig(self.loggingConfig)
             return
-
         format = logging.Formatter('%(name)s: %(levelname)s: %(message)s')
         if self.debugLog:
             handler = logging.FileHandler(self.debugLog)
         else:
             handler = logging.StreamHandler(self.logStream)
         handler.setFormatter(format)
-
         logger = logging.getLogger('nose')
         logger.propagate = 0
-
-        # only add our default handler if there isn't already one there
-        # this avoids annoying duplicate log messages.
         found = False
         if self.debugLog:
             debugLogAbsPath = os.path.abspath(self.debugLog)
             for h in logger.handlers:
-                if type(h) == logging.FileHandler and \
-                        h.baseFilename == debugLogAbsPath:
+                if (
+                    type(h) == logging.FileHandler
+                    and h.baseFilename == debugLogAbsPath
+                ):
                     found = True
         else:
             for h in logger.handlers:
-                if type(h) == logging.StreamHandler and \
-                        h.stream == self.logStream:
+                if (
+                    type(h) == logging.StreamHandler
+                    and h.stream == self.logStream
+                ):
                     found = True
         if not found:
             logger.addHandler(handler)
-
-        # default level
         lvl = logging.WARNING
         if self.verbosity >= 5:
             lvl = 0
@@ -462,31 +423,27 @@ class Config(object):
             "higher verbosity for greater detail"
         )
         parser.add_option(
-            "-v", "--verbose",
-            action="count", dest="verbosity",
-            default=self.verbosity,
+            "-v", "--verbose", action="count",
+            dest="verbosity", default=self.verbosity,
             help="Be more verbose. [NOSE_VERBOSE]"
         )
         parser.add_option(
             "--verbosity", action="store", dest="verbosity",
-            metavar='VERBOSITY',
-            type="int", help="Set verbosity; --verbosity=2 is "
-            "the same as -v"
+            metavar='VERBOSITY', type="int",
+            help="Set verbosity; --verbosity=2 is the same as -v"
         )
         parser.add_option(
             "-q", "--quiet", action="store_const", const=0, dest="verbosity",
             help="Be less verbose"
         )
         parser.add_option(
-            "-c", "--config", action="append", dest="files",
-            metavar="FILES",
+            "-c", "--config", action="append", dest="files", metavar="FILES",
             help="Load configuration from config file(s). May be specified "
             "multiple times; in that case, all config files will be "
             "loaded and combined"
         )
         parser.add_option(
-            "-w", "--where", action="append", dest="where",
-            metavar="WHERE",
+            "-w", "--where", action="append", dest="where", metavar="WHERE",
             help="Look for tests in this directory. "
             "May be specified multiple times. The first directory passed "
             "will be used as the working directory, in place of the current "
@@ -494,8 +451,7 @@ class Config(object):
             "to the list of tests to execute. [NOSE_WHERE]"
         )
         parser.add_option(
-            "--py3where", action="append", dest="py3where",
-            metavar="PY3WHERE",
+            "--py3where", action="append", dest="py3where", metavar="PY3WHERE",
             help="Look for tests in this directory under Python 3.x. "
             "Functions the same as 'where', but only applies if running under "
             "Python 3.x or above.  Note that, if present under 3.x, this "
@@ -520,8 +476,7 @@ class Config(object):
             "switch."
         )
         parser.add_option(
-            "-l", "--debug", action="store",
-            dest="debug", default=self.debug,
+            "-l", "--debug", action="store", dest="debug", default=self.debug,
             help="Activate debug logging for one or more systems. "
             "Available debug loggers: nose, nose.importer, "
             "nose.inspector, nose.plugins, nose.result and "
@@ -533,9 +488,8 @@ class Config(object):
             "(default: sys.stderr)"
         )
         parser.add_option(
-            "--logging-config", "--log-config",
-            dest="loggingConfig", action="store",
-            default=self.loggingConfig, metavar="FILE",
+            "--logging-config", "--log-config", dest="loggingConfig",
+            action="store", default=self.loggingConfig, metavar="FILE",
             help="Load logging config from this file -- bypasses all other"
             " logging config settings."
         )
@@ -543,8 +497,7 @@ class Config(object):
             "-I", "--ignore-files", action="append", dest="ignoreFiles",
             metavar="REGEX",
             help="Completely ignore any file that matches this regular "
-            "expression. Takes precedence over any other settings or "
-            "plugins. "
+            "expression. Takes precedence over any other settings or plugins. "
             "Specifying this option will replace the default setting. "
             "Specify this option multiple times "
             "to add more regular expressions [NOSE_IGNORE_FILES]"
@@ -571,8 +524,7 @@ class Config(object):
         )
         parser.add_option(
             "-P", "--no-path-adjustment", action="store_false",
-            dest="addPaths",
-            default=self.addPaths,
+            dest="addPaths", default=self.addPaths,
             help="Don't make any changes to sys.path when "
             "loading tests [NOSE_NOPATH]"
         )
@@ -607,10 +559,8 @@ class Config(object):
             help="Prevent nose from byte-compiling the source into .pyc files "
             "while nose is scanning for and running tests."
         )
-
         self.plugins.loadPlugins()
         self.pluginOpts(parser)
-
         self.parser = parser
         return parser
 
@@ -662,9 +612,8 @@ def all_config_files():
     return user
 
 
-# used when parsing config files
 def flag(val):
-    """Does the value look like an on/off flag?"""
+    """For parsing config files. Does the value look like an on/off flag?"""
     if val == 1:
         return True
     elif val == 0:
