@@ -23,7 +23,6 @@ from nose.suite import ContextSuiteFactory, ContextList, LazySuite
 from nose.pyversion import sort_list, cmp_to_key
 import collections
 
-
 log = logging.getLogger(__name__)
 op_normpath = os.path.normpath
 op_abspath = os.path.abspath
@@ -48,10 +47,7 @@ class TestLoader(unittest.TestLoader):
 
     def __init__(self, config=None, importer=None, workingDir=None,
                  selector=None):
-        """Initialize a test loader.
-
-        Parameters (all optional):
-
+        """Initialize a test loader. Parameters (all optional):
         * config: provide a `nose.config.Config`_ or other config class
           instance; if not provided a `nose.config.Config`_ with
           default values is used.
@@ -64,7 +60,7 @@ class TestLoader(unittest.TestLoader):
         * selector: a selector class or instance. If a class is
           provided, it will be instantiated with one argument, the
           current config. If not provided, a `nose.selector.Selector`_
-          is used. """
+          is used."""
         if config is None:
             config = Config()
         if importer is None:
@@ -86,8 +82,6 @@ class TestLoader(unittest.TestLoader):
         unittest.TestLoader.__init__(self)
 
     def getTestCaseNames(self, testCaseClass):
-        """Override to select with selector, unless
-        config.getTestCaseNamesCompat is True"""
         if self.config.getTestCaseNamesCompat:
             return unittest.TestLoader.getTestCaseNames(self, testCaseClass)
 
@@ -100,7 +94,6 @@ class TestLoader(unittest.TestLoader):
             return sel.wantMethod(item)
 
         cases = list(filter(wanted, dir(testCaseClass)))
-        # add runTest if nothing else picked
         if not cases and hasattr(testCaseClass, 'runTest'):
             cases = ['runTest']
         if self.sortTestMethodsUsing:
@@ -108,8 +101,6 @@ class TestLoader(unittest.TestLoader):
         return cases
 
     def _haveVisited(self, path):
-        # For cases where path is None, we always pretend we haven't visited
-        # them.
         if path is None:
             return False
         return path in self._visitedPaths
@@ -121,14 +112,12 @@ class TestLoader(unittest.TestLoader):
     def loadTestsFromDir(self, path):
         """Load tests from the directory at path. This is a generator
         -- each suite of tests from a module or other file is yielded
-        and is expected to be executed before the next file is
-        examined."""
+        and is expected to be executed before the next file is examined."""
         log.debug("load from dir %s", path)
         plugins = self.config.plugins
         plugins.beforeDirectory(path)
         if self.config.addPaths:
             paths_added = add_path(path, self.config)
-
         entries = os.listdir(path)
         sort_list(entries, regex_last_key(self.config.testMatch))
         for entry in entries:
@@ -151,11 +140,9 @@ class TestLoader(unittest.TestLoader):
                         continue
                     wanted = self.selector.wantDirectory(entry_path)
             is_package = ispackage(entry_path)
-
-            # Python 3.3 now implements PEP 420: Implicit Namespace Packages.
-            # As a result, it's now possible that parent paths that have a
+            # It's now possible that parent paths that have a
             # segment with the same basename as our package ends up
-            # in module.__path__.  So we have to keep track of what we've
+            # in module.__path__. So we have to keep track of what we've
             # visited, and not-revisit them again.
             if wanted and not self._haveVisited(entry_path):
                 self._addVisitedPath(entry_path)
@@ -168,12 +155,9 @@ class TestLoader(unittest.TestLoader):
                         yield self.loadTestsFromFile(entry_path)
                     plugins.afterContext()
                 elif is_package:
-                    # Load the entry as a package: given the full path,
-                    # loadTestsFromName() will figure it out
                     yield self.loadTestsFromName(
                         entry_path, discovered=True)
                 else:
-                    # Another test dir in this one: recurse lazily
                     yield self.suiteClass(
                         lambda: self.loadTestsFromDir(entry_path))
         tests = []
@@ -200,16 +184,13 @@ class TestLoader(unittest.TestLoader):
             tests = [test for test in
                      self.config.plugins.loadTestsFromFile(filename)]
             if tests:
-                # Plugins can yield False to indicate that they were
-                # unable to load tests from a file, but it was not an
-                # error -- the file just had no tests to load.
                 tests = [_f for _f in tests if _f]
                 return self.suiteClass(tests)
             else:
-                # Nothing was able to even try to load from this file
-                open(filename, 'r').close()  # trigger os error
-                raise ValueError("Unable to load tests from file %s"
-                                 % filename)
+                open(filename, 'r').close()
+                raise ValueError(
+                    "Unable to load tests from file %s" % filename
+                )
         except (KeyboardInterrupt, SystemExit):
             raise
         except Exception:
@@ -219,15 +200,15 @@ class TestLoader(unittest.TestLoader):
                          address=(filename, None, None))])
 
     def loadTestsFromGenerator(self, generator, module):
-        """Lazy-load tests from a generator function. The generator function
-        may yield either:
+        """Lazy-load tests from a generator function.
+        The generator function may yield either:
         * a callable, or
         * a function name resolvable within the same module """
         def generate(g=generator, m=module):
             try:
                 for test in g():
                     test_func, arg = self.parseGeneratedTest(test)
-                    if not isinstance(test_func, collections.Callable):
+                    if not isinstance(test_func, collections.abc.Callable):
                         test_func = getattr(m, test_func)
                     yield FunctionTestCase(test_func, arg=arg, descriptor=g)
             except KeyboardInterrupt:
@@ -240,16 +221,11 @@ class TestLoader(unittest.TestLoader):
 
     def loadTestsFromGeneratorMethod(self, generator, cls):
         """Lazy-load tests from a generator method.
-
         This is more complicated than loading from a generator function,
         since a generator method may yield:
-
         * a function
         * a bound or unbound method, or
-        * a method name
-        """
-        # convert the unbound generator method
-        # into a bound method so it can be called below
+        * a method name """
         if hasattr(generator, 'im_class'):
             cls = generator.__self__.__class__
         inst = cls()
@@ -260,40 +236,32 @@ class TestLoader(unittest.TestLoader):
             try:
                 for test in g():
                     test_func, arg = self.parseGeneratedTest(test)
-                    if not isinstance(test_func, collections.Callable):
+                    if not isinstance(test_func, collections.abc.Callable):
                         test_func = unbound_method(c, getattr(c, test_func))
                     if ismethod(test_func):
                         yield MethodTestCase(test_func, arg=arg, descriptor=g)
-                    elif isinstance(test_func, collections.Callable):
-                        # In this case we're forcing the 'MethodTestCase'
-                        # to run the inline function as its test call,
-                        # but using the generator method as the 'method of
-                        # record' (so no need to pass it as the descriptor)
+                    elif isinstance(test_func, collections.abc.Callable):
                         yield MethodTestCase(g, test=test_func, arg=arg)
                     else:
                         yield Failure(
                             TypeError,
-                            "%s is not a callable or method" % test_func)
+                            "%s is not a callable or method" % test_func
+                        )
             except KeyboardInterrupt:
                 raise
             except Exception:
                 exc = sys.exc_info()
-                yield Failure(exc[0], exc[1], exc[2],
-                              address=test_address(generator))
+                yield Failure(
+                    exc[0], exc[1], exc[2], address=test_address(generator)
+                )
         return self.suiteClass(generate, context=generator, can_split=False)
 
     def loadTestsFromModule(self, module, path=None, discovered=False):
-        """Load all tests from module and return a suite containing
-        them. If the module has been discovered and is not test-like,
-        the suite will be empty by default, though plugins may add
-        their own tests."""
+        """Load all tests from module and return a suite containing them."""
         log.debug("Load from module %s", module)
         tests = []
         test_classes = []
         test_funcs = []
-        # For *discovered* modules, we only load tests when the module looks
-        # testlike. For modules we've been directed to load, we always
-        # look for tests. (discovered is set to True by loadTestsFromDir)
         if not discovered or self.selector.wantModule(module):
             for item in dir(module):
                 test = getattr(module, item, None)
@@ -309,12 +277,9 @@ class TestLoader(unittest.TestLoader):
                 self.makeTest(t, parent=module)
                 for t in test_classes + test_funcs
             ]
-
         module_paths = getattr(module, '__path__', [])
-
         if path:
             path = os.path.normcase(os.path.realpath(path))
-
         for module_path in module_paths:
             log.debug("Load tests from module path %s?", module_path)
             log.debug("path: %s os.path.realpath(%s): %s",
@@ -327,10 +292,8 @@ class TestLoader(unittest.TestLoader):
                 # directory before trying to load from it.
                 if os.path.isdir(module_path):
                     tests.extend(self.loadTestsFromDir(module_path))
-
         for test in self.config.plugins.loadTestsFromModule(module, path):
             tests.append(test)
-
         return self.suiteClass(ContextList(tests, context=module))
 
     def loadTestsFromName(self, name, module=None, discovered=False):
@@ -345,15 +308,6 @@ class TestLoader(unittest.TestLoader):
             return suite(plug_tests)
         addr = TestAddress(name, workingDir=self.workingDir)
         if module:
-            # Two cases:
-            #  name is class.foo
-            #    The addr will be incorrect, since it thinks class.foo is
-            #    a dotted module name. It's actually a dotted attribute
-            #    name. In this case we want to use the full submitted
-            #    name as the name to load from the module.
-            #  name is module:class.foo
-            #    The addr will be correct. The part we want is the part after
-            #    the :, which is in addr.call.
             if addr.call:
                 name = addr.call
             parent, obj = self.resolve(name, module)
@@ -368,8 +322,9 @@ class TestLoader(unittest.TestLoader):
             if isinstance(obj, Failure):
                 return suite([obj])
             else:
-                return suite(ContextList([self.makeTest(obj, parent)],
-                                         context=parent))
+                return suite(
+                    ContextList([self.makeTest(obj, parent)], context=parent)
+                )
         else:
             if addr.module:
                 try:
@@ -394,8 +349,7 @@ class TestLoader(unittest.TestLoader):
                     return self.loadTestsFromName(addr.call, module)
                 else:
                     return self.loadTestsFromModule(
-                        module, addr.filename,
-                        discovered=discovered)
+                        module, addr.filename, discovered=discovered)
             elif addr.filename:
                 path = addr.filename
                 if addr.call:
@@ -410,23 +364,18 @@ class TestLoader(unittest.TestLoader):
                     return self.loadTestsFromName(addr.call, module=package)
                 else:
                     if op_isdir(path):
-                        # In this case we *can* be lazy since we know
-                        # that each module in the dir will be fully
-                        # loaded before its tests are executed; we
-                        # also know that we're not going to be asked
-                        # to load from . and ./some_module.py *as part
-                        # of this named test load*
-                        return LazySuite(
-                            lambda: self.loadTestsFromDir(path))
+                        return LazySuite(lambda: self.loadTestsFromDir(path))
                     elif op_isfile(path):
                         return self.loadTestsFromFile(path)
                     else:
                         return suite([
-                                Failure(OSError, "No such file %s" % path,
-                                        address=addr.totuple())])
+                            Failure(
+                                OSError,
+                                "No such file %s" % path,
+                                address=addr.totuple()
+                            )
+                        ])
             else:
-                # just a function? what to do? I think it can only be
-                # handled when module is not None
                 return suite([
                     Failure(ValueError, "Unresolvable test name %s" % name,
                             address=addr.totuple())])
@@ -449,9 +398,6 @@ class TestLoader(unittest.TestLoader):
         plugins = self.config.plugins
         for case in plugins.loadTestsFromTestCase(testCaseClass):
             cases.append(case)
-        # For efficiency in the most common case, just call and return from
-        # super. This avoids having to extract cases and rebuild a context
-        # suite when there are no plugin-contributed cases.
         if not cases:
             return super(TestLoader, self).loadTestsFromTestCase(testCaseClass)
         cases.extend(
@@ -460,11 +406,7 @@ class TestLoader(unittest.TestLoader):
         return self.suiteClass(cases)
 
     def loadTestsFromTestClass(self, cls):
-        """Load tests from a test class that is *not* a unittest.TestCase
-        subclass.
-        In this case, we can't depend on the class's `__init__` taking method
-        name arguments, so we have to compose a MethodTestCase for each
-        method in the class that looks testlike."""
+        """Load tests from a class that is NOT a unittest.TestCase subclass."""
         def wanted(attr, cls=cls, sel=self.selector):
             item = getattr(cls, attr, None)
             if isfunction(item):
@@ -494,8 +436,7 @@ class TestLoader(unittest.TestLoader):
             return Failure(exc[0], exc[1], exc[2], address=addr)
 
     def _makeTest(self, obj, parent=None):
-        """Given a test object and its parent, return a test case
-        or test suite."""
+        """Given a test object and its parent, return a test case or suite."""
         plug_tests = []
         try:
             addr = test_address(obj)
@@ -513,16 +454,12 @@ class TestLoader(unittest.TestLoader):
         except Exception:
             exc = sys.exc_info()
             return Failure(exc[0], exc[1], exc[2], address=addr)
-
         if (
             isfunction(obj)
             and parent
             and not isinstance(parent, types.ModuleType)
         ):
-            # This is a Python 3.x 'unbound method'. Wrap it with its
-            # associated class.
             obj = unbound_method(parent, obj)
-
         if isinstance(obj, unittest.TestCase):
             return obj
         elif isclass(obj):
@@ -550,18 +487,17 @@ class TestLoader(unittest.TestLoader):
             else:
                 return FunctionTestCase(obj)
         else:
-            return Failure(TypeError,
-                           "Can't make a test from %s" % obj,
-                           address=addr)
+            return Failure(
+                TypeError, "Can't make a test from %s" % obj, address=addr
+            )
 
     def resolve(self, name, module):
-        """Resolve name within module"""
+        """Resolve name within module."""
         obj = module
         parts = name.split('.')
         for part in parts:
             parent, obj = obj, getattr(obj, part, None)
         if obj is None:
-            # no such test
             obj = Failure(ValueError, "No such test %s" % name)
         return parent, obj
 
