@@ -1,95 +1,61 @@
 """
 Overview
 ========
-
 The multiprocess plugin enables you to distribute your test run among a set of
 worker processes that run tests in parallel. This can speed up CPU-bound test
 runs (as long as the number of work processeses is around the number of
 processors or cores available), but is mainly useful for IO-bound tests that
 spend most of their time waiting for data to arrive from someplace else.
-
-.. note ::
-
-   See :doc:`../doc_tests/test_multiprocess/multiprocess` for
-   additional documentation and examples. Use of this plugin on python
-   2.5 or earlier requires the multiprocessing_ module, also available
-   from PyPI.
-
 .. _multiprocessing : http://code.google.com/p/python-multiprocessing/
 
 How tests are distributed
 =========================
-
-The ideal case would be to dispatch each test to a worker process
-separately. This ideal is not attainable in all cases, however, because many
-test suites depend on context (class, module or package) fixtures.
-
+The ideal case would be to dispatch each test to a worker process separately.
+This ideal is not attainable in all cases, however, because many test suites
+depend on context (class, module, or package) fixtures.
 The plugin can't know (unless you tell it -- see below!) if a context fixture
 can be called many times concurrently (is re-entrant), or if it can be shared
 among tests running in different processes. Therefore, if a context has
-fixtures, the default behavior is to dispatch the entire suite to a worker as
-a unit.
+fixtures, the default behavior is to dispatch the suite to a worker as a unit.
 
 Controlling distribution
-^^^^^^^^^^^^^^^^^^^^^^^^
-
-There are two context-level variables that you can use to control this default
-behavior.
-
-If a context's fixtures are re-entrant, set ``_multiprocess_can_split_ = True``
+========================
+There are two context-level variables to control this default behavior:
+* If a context's fixtures are re-entrant, set `_multiprocess_can_split_ = True`
 in the context, and the plugin will dispatch tests in suites bound to that
 context as if the context had no fixtures. This means that the fixtures will
 execute concurrently and multiple times, typically once per test.
-
-If a context's fixtures can be shared by tests running in different processes
--- such as a package-level fixture that starts an external http server or
-initializes a shared database -- then set ``_multiprocess_shared_ = True`` in
-the context. These fixtures will then execute in the primary nose process, and
-tests in those contexts will be individually dispatched to run in parallel.
+* If a context's fixtures can be shared by tests running in different processes
+(such as a package-level fixture that starts an external http server or
+initializes a shared database) then set ``_multiprocess_shared_ = True`` in
+the context. These fixtures will then execute in the primary nose process,
+and tests in those contexts will be individually dispatched to run in parallel.
 
 How results are collected and reported
 ======================================
-
 As each test or suite executes in a worker process, results (failures, errors,
-and specially handled exceptions like SkipTest) are collected in that
-process. When the worker process finishes, it returns results to the main
-nose process. There, any progress output is printed (dots!), and the
-results from the test run are combined into a consolidated result
-set. When results have been received for all dispatched tests, or all
-workers have died, the result summary is output as normal.
+and specially handled exceptions like SkipTest) are collected in that process.
+When the worker process finishes, it returns results to the main nose process.
+There, any progress output is printed (dots!), and the results from the
+test run are combined into a consolidated result set.
+When results have been received for all dispatched tests,
+or all workers have died, the result summary is output as normal.
 
 Beware!
 =======
-
-Not all test suites will benefit from, or even operate correctly using, this
+Not all test suites will benefit from, or even operate correctly using this
 plugin. For example, CPU-bound tests will run more slowly if you don't have
-multiple processors. There are also some differences in plugin
-interactions and behaviors due to the way in which tests are dispatched and
-loaded. In general, test loading under this plugin operates as if it were
-always in directed mode instead of discovered mode. For instance, doctests
-in test modules will always be found when using this plugin with the doctest
-plugin.
-
+multiple processors. There are also some differences in plugin interactions
+and behaviors due to the way in which tests are dispatched and loaded.
+In general, tests loaded under this plugin operate as if they were always in
+directed mode instead of discovered mode. For instance, doctests in test
+modules will always be found when using this plugin with the doctest plugin.
 But the biggest issue you will face is probably concurrency. Unless you
 have kept your tests as religiously pure unit tests, with no side-effects, no
 ordering issues, and no external dependencies, chances are you will experience
 odd, intermittent and unexplainable failures and errors when using this
-plugin. This doesn't necessarily mean the plugin is broken; it may mean that
-your test suite is not safe for concurrency.
-
-New Features in 1.1.0
-=====================
-
-* functions generated by test generators are now added to the worker queue
-  making them multi-threaded.
-* fixed timeout functionality, now functions will be terminated with a
-  TimedOutException exception when they exceed their execution time. The
-  worker processes are not terminated.
-* added ``--process-restartworker`` option to restart workers once they are
-  done, this helps control memory usage. Sometimes memory leaks can accumulate
-  making long runs very difficult.
-* added global _instantiate_plugins to configure which plugins are started
-  on the worker processes. """
+plugin. This doesn't necessarily mean the plugin is broken;
+it may mean that your test suite is not safe for concurrency."""
 import logging
 import os
 import sys
@@ -105,23 +71,15 @@ from nose.plugins.base import Plugin
 from nose.pyversion import bytes_
 from nose.suite import ContextSuite
 from nose.util import test_address
-try:
-    # 2.7+
-    from unittest.runner import _WritelnDecorator
-except ImportError:
-    from unittest import _WritelnDecorator
+from unittest.runner import _WritelnDecorator
 from queue import Empty
 from warnings import warn
 from io import StringIO
 
-# this is a list of plugin classes that will be checked for and created inside
-# each worker process
 _instantiate_plugins = None
 log = logging.getLogger(__name__)
 Process = Queue = Pool = Event = Value = Array = None
 
-# have to inherit KeyboardInterrupt to it will interrupt process properly
-
 
 class TimedOutException(KeyboardInterrupt):
 
@@ -136,15 +94,8 @@ def _import_mp():
     global Process, Queue, Pool, Event, Value, Array
     try:
         from multiprocessing import Manager, Process
-        # prevent the server process created in the manager which holds Python
-        # objects and allows other processes to manipulate them using proxies
-        # to interrupt on SIGINT (keyboardinterrupt) so that the communication
-        # channel between subprocesses and main process is still usable after
-        # ctrl+C is received in the main process.
         old = signal.signal(signal.SIGINT, signal.SIG_IGN)
         m = Manager()
-        # reset it back so main process will receive a KeyboardInterrupt
-        # exception on ctrl+c
         signal.signal(signal.SIGINT, old)
         Queue, Pool, Event, Value, Array = (
                 m.Queue, m.Pool, m.Event, m.Value, m.Array
@@ -180,33 +131,30 @@ class MultiProcess(Plugin):
 
     def options(self, parser, env):
         """Register command-line options."""
-        parser.add_option("--processes", action="store",
-                          default=env.get('NOSE_PROCESSES', 0),
-                          dest="multiprocess_workers",
-                          metavar="NUM",
-                          help="Spread test run among this many processes. "
-                          "Set a number equal to the number of processors "
-                          "or cores in your machine for best results. "
-                          "Pass a negative number to have the number of "
-                          "processes automatically set to the number of "
-                          "cores. Passing 0 means to disable parallel "
-                          "testing. Default is 0 unless NOSE_PROCESSES is "
-                          "set. "
-                          "[NOSE_PROCESSES]")
-        parser.add_option("--process-timeout", action="store",
-                          default=env.get('NOSE_PROCESS_TIMEOUT', 10),
-                          dest="multiprocess_timeout",
-                          metavar="SECONDS",
-                          help="Set timeout for return of results from each "
-                          "test runner process. Default is 10. "
-                          "[NOSE_PROCESS_TIMEOUT]")
-        parser.add_option("--process-restartworker", action="store_true",
-                          default=env.get('NOSE_PROCESS_RESTARTWORKER', False),
-                          dest="multiprocess_restartworker",
-                          help="If set, will restart each worker process once"
-                          " their tests are done, this helps control memory "
-                          "leaks from killing the system. "
-                          "[NOSE_PROCESS_RESTARTWORKER]")
+        parser.add_option(
+            "--processes", action="store",
+            default=env.get('NOSE_PROCESSES', 0),
+            dest="multiprocess_workers", metavar="NUM",
+            help="Spread test run among this many processes. "
+            "Set a number equal to the number of processors "
+            "or cores in your machine for best results. "
+            "Pass a negative number to have the number of "
+            "processes automatically set to the number of cores. "
+            "Passing 0 means to disable parallel testing. "
+            "Default is 0 unless NOSE_PROCESSES is set. [NOSE_PROCESSES]")
+        parser.add_option(
+            "--process-timeout", action="store",
+            default=env.get('NOSE_PROCESS_TIMEOUT', 10),
+            dest="multiprocess_timeout", metavar="SECONDS",
+            help="Set timeout for return of results from each "
+            "test runner process. Default is 10. [NOSE_PROCESS_TIMEOUT]")
+        parser.add_option(
+            "--process-restartworker", action="store_true",
+            default=env.get('NOSE_PROCESS_RESTARTWORKER', False),
+            dest="multiprocess_restartworker",
+            help="If set, will restart each worker process once"
+            " their tests are done, this helps control memory "
+            "leaks from killing the system. [NOSE_PROCESS_RESTARTWORKER]")
 
     def configure(self, options, config):
         """Configure plugin."""
@@ -217,9 +165,8 @@ class MultiProcess(Plugin):
         if not hasattr(options, 'multiprocess_workers'):
             self.enabled = False
             return
-        # don't start inside of a worker process
         if config.worker:
-            return
+            return  # Don't start inside of a worker process
         self.config = config
         try:
             workers = int(options.multiprocess_workers)
@@ -230,15 +177,9 @@ class MultiProcess(Plugin):
             if Process is None:
                 self.enabled = False
                 return
-            # Negative number of workers will cause multiprocessing to hang.
-            # Set the number of workers to the CPU count to avoid this.
             if workers < 0:
-                try:
-                    import multiprocessing
-                    workers = multiprocessing.cpu_count()
-                except NotImplementedError:
-                    self.enabled = False
-                    return
+                import multiprocessing
+                workers = multiprocessing.cpu_count()
             self.enabled = True
             self.config.multiprocess_workers = workers
             t = float(options.multiprocess_timeout)
@@ -254,11 +195,9 @@ class MultiProcess(Plugin):
 
     def prepareTestRunner(self, runner):
         """Replace test runner with MultiProcessTestRunner."""
-        # replace with our runner class
-        return MultiProcessTestRunner(stream=runner.stream,
-                                      verbosity=self.config.verbosity,
-                                      config=self.config,
-                                      loaderClass=self.loaderClass)
+        return MultiProcessTestRunner(
+            stream=runner.stream, verbosity=self.config.verbosity,
+            config=self.config, loaderClass=self.loaderClass)
 
 
 def signalhandler(sig, frame):
@@ -266,8 +205,7 @@ def signalhandler(sig, frame):
 
 
 class MultiProcessTestRunner(TextTestRunner):
-    # max time to wait to terminate a process that does not
-    # respond to SIGILL
+    # Max time to wait to terminate a process that does not respond to SIGILL.
     waitkilltime = 5.0
 
     def __init__(self, **kw):
@@ -275,8 +213,6 @@ class MultiProcessTestRunner(TextTestRunner):
         super(MultiProcessTestRunner, self).__init__(**kw)
 
     def collect(self, test, testQueue, tasks, to_teardown, result):
-        # dispatch and collect results
-        # put indexes only on queue because tests aren't picklable
         for case in self.nextBatch(test):
             log.debug("Next batch %s (%s)", case, type(case))
             if (
@@ -284,14 +220,13 @@ class MultiProcessTestRunner(TextTestRunner):
                 and isinstance(case.test, failure.Failure)
             ):
                 log.debug("Case is a Failure")
-                case(result)  # run here to capture the failure
+                case(result)
                 continue
-            # handle shared fixtures
             if isinstance(
                 case, ContextSuite
             ) and case.context is failure.Failure:
                 log.debug("Case is a Failure")
-                case(result)  # run here to capture the failure
+                case(result)
                 continue
             elif isinstance(case, ContextSuite) and self.sharedFixtures(case):
                 log.debug("%s has shared fixtures", case)
@@ -307,19 +242,14 @@ class MultiProcessTestRunner(TextTestRunner):
                     if case.factory:
                         ancestors = case.factory.context.get(case, [])
                         for an in ancestors[:2]:
-                            # log.debug('reset ancestor %s', an)
                             if getattr(an, '_multiprocess_shared_', False):
                                 an._multiprocess_can_split_ = True
-                            # an._multiprocess_shared_ = False
                     self.collect(case, testQueue, tasks, to_teardown, result)
-
             else:
                 test_addr = self.addtask(testQueue, tasks, case)
                 log.debug(
                     "Queued test %s (%s) to %s",
-                    len(tasks),
-                    test_addr,
-                    testQueue,
+                    len(tasks), test_addr, testQueue,
                 )
 
     def startProcess(
@@ -352,8 +282,7 @@ class MultiProcessTestRunner(TextTestRunner):
         return p
 
     def run(self, test):
-        """
-        Execute the test (which may be a test suite). If the test is a suite,
+        """Execute the test (which may be a suite). If the test is a suite,
         distribute it out among as many processes as have been configured, at
         as fine a level as is possible given the context fixtures defined in
         the suite or any sub-suites."""
@@ -361,12 +290,9 @@ class MultiProcessTestRunner(TextTestRunner):
         wrapper = self.config.plugins.prepareTest(test)
         if wrapper is not None:
             test = wrapper
-
-        # plugins can decorate or capture the output stream
         wrapped = self.config.plugins.setOutputStream(self.stream)
         if wrapped is not None:
             self.stream = wrapped
-
         testQueue = Queue()
         resultQueue = Queue()
         tasks = []
@@ -374,12 +300,9 @@ class MultiProcessTestRunner(TextTestRunner):
         workers = []
         to_teardown = []
         shouldStop = Event()
-
         result = self._makeResult()
         start = time.time()
-
         self.collect(test, testQueue, tasks, to_teardown, result)
-
         log.debug("Starting %s workers", self.config.multiprocess_workers)
         for i in range(self.config.multiprocess_workers):
             p = self.startProcess(
@@ -387,20 +310,14 @@ class MultiProcessTestRunner(TextTestRunner):
             )
             workers.append(p)
             log.debug("Started worker process %s", i+1)
-
         total_tasks = len(tasks)
-        # need to keep track of the next time to check for timeouts in case
-        # more than one process times out at the same time.
         nexttimeout = self.config.multiprocess_timeout
         thrownError = None
-
         try:
             while tasks:
                 log.debug(
                     "Waiting for results (%s/%s tasks), next timeout=%.3fs",
-                    len(completed),
-                    total_tasks,
-                    nexttimeout,
+                    len(completed), total_tasks, nexttimeout,
                 )
                 try:
                     iworker, addr, newtask_addrs, batch_result = (
@@ -408,9 +325,7 @@ class MultiProcessTestRunner(TextTestRunner):
                     )
                     log.debug(
                         'Results received for worker %d, %s, new tasks: %d',
-                        iworker,
-                        addr,
-                        len(newtask_addrs),
+                        iworker, addr, len(newtask_addrs),
                     )
                     try:
                         try:
@@ -418,8 +333,7 @@ class MultiProcessTestRunner(TextTestRunner):
                         except ValueError:
                             log.warn(
                                 'worker %s failed to remove from tasks: %s',
-                                iworker,
-                                addr,
+                                iworker, addr,
                             )
                         total_tasks += len(newtask_addrs)
                         tasks.extend(newtask_addrs)
@@ -430,18 +344,12 @@ class MultiProcessTestRunner(TextTestRunner):
                         completed.append([addr, batch_result])
                     self.consolidate(result, batch_result)
                     if (
-                        self.config.stopOnError
-                        and not result.wasSuccessful()
+                        self.config.stopOnError and not result.wasSuccessful()
                     ):
-                        # set the stop condition
                         shouldStop.set()
                         break
                     if self.config.multiprocess_restartworker:
                         log.debug('joining worker %s', iworker)
-                        # wait for working, but not that important if worker
-                        # cannot be joined in fact, for workers that add to
-                        # testQueue, they will not terminate until all their
-                        # items are read
                         workers[iworker].join(timeout=1)
                         if not shouldStop.is_set() and not testQueue.empty():
                             log.debug(
@@ -452,12 +360,11 @@ class MultiProcessTestRunner(TextTestRunner):
                                 testQueue,
                                 resultQueue,
                                 shouldStop,
-                                result
+                                result,
                             )
                 except Empty:
-                    log.debug("Timed out with %s tasks pending "
-                              "(empty testQueue=%r): %s",
-                              len(tasks), testQueue.empty(), str(tasks))
+                    msg = "Timeout - %s tasks pending (empty testQueue=%r): %s"
+                    log.debug(msg, len(tasks), testQueue.empty(), str(tasks))
                     any_alive = False
                     for iworker, w in enumerate(workers):
                         if w.is_alive():
@@ -469,9 +376,8 @@ class MultiProcessTestRunner(TextTestRunner):
                                 > self.config.multiprocess_timeout - 0.1
                             ):
                                 log.debug(
-                                    'worker %d has finished its work item, '
-                                    'but is not exiting? do we wait for it?',
-                                    iworker,
+                                    'Worker %d finished its work item, but is '
+                                    'not exiting. Do we wait for it?', iworker,
                                 )
                             else:
                                 any_alive = True
@@ -480,17 +386,9 @@ class MultiProcessTestRunner(TextTestRunner):
                                 and timeprocessing
                                 > self.config.multiprocess_timeout - 0.1
                             ):
-                                log.debug(
-                                    'timed out worker %s: %s',
-                                    iworker, worker_addr
-                                )
+                                msg = 'Timed out worker %s: %s'
+                                log.debug(msg, iworker, worker_addr)
                                 w.currentaddr.value = bytes_('')
-                                # If the process is in C++ code,
-                                # sending a SIGILL might not send a python
-                                # KeybordInterrupt exception,
-                                # therefore, send multiple signals until an
-                                # exception is caught. If this takes too long,
-                                # then terminate the process
                                 w.keyboardCaught.clear()
                                 startkilltime = time.time()
                                 while (
@@ -501,16 +399,9 @@ class MultiProcessTestRunner(TextTestRunner):
                                         time.time() - startkilltime
                                         > self.waitkilltime
                                     ):
-                                        # have to terminate...
-                                        log.error(
-                                            "terminating worker %s",
-                                            iworker
-                                        )
+                                        msg = "terminating worker %s"
+                                        log.error(msg, iworker)
                                         w.terminate()
-                                        # there is a small probability that the
-                                        # terminated process might send result,
-                                        # which has to be specially handled or
-                                        # else processes might get orphaned.
                                         workers[iworker] = w = (
                                             self.startProcess(
                                                 iworker,
@@ -524,14 +415,11 @@ class MultiProcessTestRunner(TextTestRunner):
                                     os.kill(w.pid, signal.SIGILL)
                                     time.sleep(0.1)
                     if not any_alive and testQueue.empty():
-                        log.debug("All workers dead")
+                        log.debug("All workers are dead")
                         break
                 nexttimeout = self.config.multiprocess_timeout
                 for w in workers:
-                    if (
-                        w.is_alive()
-                        and len(w.currentaddr.value) > 0
-                    ):
+                    if w.is_alive() and len(w.currentaddr.value) > 0:
                         timeprocessing = time.time() - w.currentstart.value
                         if timeprocessing <= self.config.multiprocess_timeout:
                             nexttimeout = min(
@@ -542,11 +430,9 @@ class MultiProcessTestRunner(TextTestRunner):
             log.debug(
                 "Completed %s tasks (%s remain)", len(completed), len(tasks)
             )
-
         except (KeyboardInterrupt, SystemExit) as e:
             log.info('parent received ctrl-c when waiting for test results')
             thrownError = e
-            # resultQueue.get(False)
             result.addError(test, sys.exc_info())
         try:
             for case in to_teardown:
@@ -557,21 +443,15 @@ class MultiProcessTestRunner(TextTestRunner):
                     raise
                 except Exception:
                     result.addError(case, sys.exc_info())
-
             stop = time.time()
-
-            # first write since can freeze on shutting down processes
             result.printErrors()
             result.printSummary(start, stop)
             self.config.plugins.finalize(result)
-
             if thrownError is None:
                 log.debug("Tell all workers to stop")
                 for w in workers:
                     if w.is_alive():
                         testQueue.put('STOP', block=False)
-
-            # wait for the workers to end
             for iworker, worker in enumerate(workers):
                 if worker.is_alive():
                     log.debug('joining worker %s', iworker)
@@ -580,8 +460,7 @@ class MultiProcessTestRunner(TextTestRunner):
                         log.debug('failed to join worker %s', iworker)
         except (KeyboardInterrupt, SystemExit):
             log.info(
-                'parent received ctrl-c when shutting down: '
-                'stop all processes'
+                'parent received ctrl-c when shutting down: stop all processes'
             )
             for worker in workers:
                 if worker.is_alive():
@@ -595,8 +474,6 @@ class MultiProcessTestRunner(TextTestRunner):
     def addtask(testQueue, tasks, case):
         arg = None
         if isinstance(case, nose.case.Test) and hasattr(case.test, 'arg'):
-            # this removes the top level descriptor and allows real function
-            # name to be returned
             case.test.descriptor = None
             arg = case.test.arg
         test_addr = MultiProcessTestRunner.address(case)
@@ -622,8 +499,6 @@ class MultiProcessTestRunner(TextTestRunner):
             else:
                 parts.append(mod)
         else:
-            # strip __init__.py(c) from end of file part
-            # if present, having it there confuses loader
             dirname, basename = os.path.split(file)
             if basename.startswith('__init__'):
                 file = dirname
@@ -634,8 +509,7 @@ class MultiProcessTestRunner(TextTestRunner):
     address = staticmethod(address)
 
     def nextBatch(self, test):
-        # allows tests or suites to mark themselves as not safe
-        # for multiprocess execution
+        # Tests can mark themselves as not safe for multiprocess execution.
         if hasattr(test, 'context'):
             if not getattr(test.context, '_multiprocess_', True):
                 return
@@ -647,32 +521,23 @@ class MultiProcessTestRunner(TextTestRunner):
             or not getattr(test, 'can_split', True)
             or not isinstance(test, unittest.TestSuite)
         ):
-            # regular test case, or a suite with context fixtures
-            # special case: when run like nosetests path/to/module.py
-            # the top-level suite has only one item, and it shares
-            # the same context as that item. In that case, we want the
-            # item, not the top-level suite
             if isinstance(test, ContextSuite):
                 contained = list(test)
-                if (len(contained) == 1
-                    and getattr(contained[0],
-                                'context', None) == test.context):
+                if (
+                    len(contained) == 1
+                    and getattr(contained[0], 'context', None) == test.context
+                ):
                     test = contained[0]
             yield test
         else:
-            # Suite is without fixtures at this level; but it may have
-            # fixtures at any deeper level, so we need to examine it all
-            # the way down to the case level
             for case in test:
                 for batch in self.nextBatch(case):
                     yield batch
 
     def checkCanSplit(context, fixt):
-        """Callback that we use to check whether the fixtures found in a
-        context or ancestor are ones we care about.
-        Contexts can tell us that their fixtures are reentrant by setting
-        _multiprocess_can_split_. So if we see that, we return False to
-        disregard those fixtures."""
+        """Callback to check whether the fixtures found in a context or
+        ancestor are ones we care about. Contexts can tell us that their
+        fixtures are reentrant by setting _multiprocess_can_split_."""
         if not fixt:
             return False
         if getattr(context, '_multiprocess_can_split_', False):
@@ -700,9 +565,6 @@ class MultiProcessTestRunner(TextTestRunner):
         result.errors.extend(errors)
         for key, (storage, label, isfail) in list(errorClasses.items()):
             if key not in result.errorClasses:
-                # Ordinarily storage is result attribute
-                # but it's only processed through the errorClasses
-                # dict, so it's ok to fake it here
                 result.errorClasses[key] = ([], label, isfail)
             mystorage, _junk, _junk = result.errorClasses[key]
             mystorage.extend(storage)
@@ -747,9 +609,9 @@ def __runner(
 
     def makeResult():
         stream = _WritelnDecorator(StringIO())
-        result = resultClass(stream, descriptions=1,
-                             verbosity=config.verbosity,
-                             config=config)
+        result = resultClass(
+            stream, descriptions=1, verbosity=config.verbosity, config=config
+        )
         plug_result = config.plugins.prepareTestResult(result)
         if plug_result:
             return plug_result
@@ -760,14 +622,16 @@ def __runner(
         errors = [(TestLet(c), err) for c, err in result.errors]
         errorClasses = {}
         for key, (storage, label, isfail) in list(result.errorClasses.items()):
-            errorClasses[key] = ([(TestLet(c), err) for c, err in storage],
-                                 label, isfail)
+            errorClasses[key] = (
+                [(TestLet(c), err) for c, err in storage], label, isfail
+            )
         return (
             result.stream.getvalue(),
             result.testsRun,
             failures,
             errors,
-            errorClasses)
+            errorClasses
+        )
     for test_addr, arg in iter(get, 'STOP'):
         if shouldStop.is_set():
             log.exception('Worker %d STOPPED', ix)
@@ -786,7 +650,7 @@ def __runner(
             test(result)
             currentaddr.value = bytes_('')
             resultQueue.put((ix, test_addr, test.tasks, batch(result)))
-        except KeyboardInterrupt as e:  # TimedOutException:
+        except KeyboardInterrupt as e:
             timeout = isinstance(e, TimedOutException)
             if timeout:
                 keyboardCaught.set()
@@ -829,7 +693,7 @@ def __runner(
 class NoSharedFixtureContextSuite(ContextSuite):
     """Context suite that never fires shared fixtures.
     When a context sets _multiprocess_shared_, fixtures in that context
-    are executed by the main process. Using this suite class prevents them
+    are executed by the main process. Using this class prevents them
     from executing in the runner process as well."""
     testQueue = None
     tasks = None
@@ -847,9 +711,9 @@ class NoSharedFixtureContextSuite(ContextSuite):
 
     def run(self, result):
         """Run tests in suite inside of suite fixtures."""
-        # proxy the result for myself
-        log.debug("suite %s (%s) run called, tests: %s",
-                  id(self), self, self._tests)
+        log.debug(
+            "suite %s (%s) run called, tests: %s", id(self), self, self._tests
+        )
         if self.resultProxy:
             result, orig = self.resultProxy(result, self), result
         else:
@@ -865,10 +729,7 @@ class NoSharedFixtureContextSuite(ContextSuite):
             return
         try:
             for test in self._tests:
-                if (
-                    isinstance(test, nose.case.Test)
-                    and self.arg is not None
-                ):
+                if isinstance(test, nose.case.Test) and self.arg is not None:
                     test.test.arg = self.arg
                 else:
                     test.arg = self.arg
@@ -877,10 +738,6 @@ class NoSharedFixtureContextSuite(ContextSuite):
                 if result.shouldStop:
                     log.debug("stopping")
                     break
-                # each nose.case.Test will create its own result proxy
-                # so the cases need the original result, to avoid proxy
-                # chains
-                # log.debug('running test %s in suite %s', test, self);
                 try:
                     test(orig)
                 except KeyboardInterrupt as e:
@@ -905,7 +762,7 @@ class NoSharedFixtureContextSuite(ContextSuite):
         finally:
             self.has_run = True
             try:
-                # log.debug('tearDown for %s', id(self));
+                # log.debug('tearDown for %s', id(self))
                 self.tearDown()
             except KeyboardInterrupt:
                 raise
