@@ -14,16 +14,9 @@ from nose.util import isclass, resolve_name, try_run
 import collections
 
 if sys.platform == 'cli':
-    if sys.version_info[:2] < (2, 6):
-        import clr
-        clr.AddReference("IronPython")
-        from IronPython.Runtime.Exceptions import StringException
-    else:
-        class StringException(Exception):
-            pass
+    class StringException(Exception):
+        pass
 log = logging.getLogger(__name__)
-
-# Singleton for default value -- see ContextSuite.__init__ below
 _def = object()
 
 
@@ -32,15 +25,11 @@ def _strclass(cls):
 
 
 class MixedContextError(Exception):
-    """Error raised when a context suite sees tests from more than
-    one context."""
     pass
 
 
 class LazySuite(unittest.TestSuite):
-    """A suite that may use a generator as its list of tests"""
     def __init__(self, tests=()):
-        """Initialize the suite. tests may be an iterable or a generator"""
         super(LazySuite, self).__init__()
         self._set_tests(tests)
 
@@ -59,7 +48,6 @@ class LazySuite(unittest.TestSuite):
     def addTest(self, test):
         self._precache.append(test)
 
-    # added to bypass run changes in 2.7's unittest
     def run(self, result):
         for test in self._tests:
             if result.shouldStop:
@@ -94,11 +82,9 @@ class LazySuite(unittest.TestSuite):
     def _set_tests(self, tests):
         self._precache = []
         is_suite = isinstance(tests, unittest.TestSuite)
-        if isinstance(tests, collections.Callable) and not is_suite:
+        if isinstance(tests, collections.abc.Callable) and not is_suite:
             self.test_generator = tests()
         elif is_suite:
-            # Suites need special treatment: they must be called like
-            # tests for their setup/teardown to run (if any)
             self.addTests([tests])
             self.test_generator = None
         else:
@@ -111,8 +97,7 @@ class LazySuite(unittest.TestSuite):
 
 
 class ContextSuite(LazySuite):
-    """A suite with context.
-    A ContextSuite executes fixtures (setup and teardown functions or
+    """ContextSuite executes fixtures (setup and teardown functions or
     methods) for the context containing its tests.
     The context may be explicitly passed. If it is not, a context (or
     nested set of contexts) will be constructed by examining the tests
@@ -165,17 +150,12 @@ class ContextSuite(LazySuite):
         return self.run(*arg, **kw)
 
     def exc_info(self):
-        """Hook for replacing error tuple output"""
         return sys.exc_info()
 
     def _exc_info(self):
-        """Bottleneck to fix up IronPython string exceptions"""
         e = self.exc_info()
         if sys.platform == 'cli':
             if isinstance(e[0], StringException):
-                # IronPython throws these StringExceptions, but
-                # traceback checks type(etype) == str. Make a real
-                # string here.
                 e = (str(e[0]), e[1], e[2])
         return e
 
@@ -201,8 +181,6 @@ class ContextSuite(LazySuite):
                 if result.shouldStop:
                     log.debug("stopping")
                     break
-                # each nose.case.Test will create its own result proxy
-                # so the cases need the original result, to avoid proxy chains
                 test(orig)
         finally:
             self.has_run = True
@@ -259,7 +237,6 @@ class ContextSuite(LazySuite):
             return
         factory = self.factory
         if factory:
-            # get a copy, since we'll be destroying it as we go
             ancestors = factory.context.get(self, [])[:]
             while ancestors:
                 ancestor = ancestors.pop()
@@ -307,8 +284,6 @@ class ContextSuite(LazySuite):
         if context is None:
             log.debug("No context to tear down")
             return
-        # for each ancestor... if the ancestor was setup
-        # and I did the setup, I can do teardown
         factory = self.factory
         if factory:
             ancestors = factory.context.get(self, []) + [context]
@@ -347,9 +322,9 @@ class ContextSuite(LazySuite):
             if isinstance(test, Test) or isinstance(test, unittest.TestSuite):
                 yield test
             else:
-                yield Test(test,
-                           config=self.config,
-                           resultProxy=self.resultProxy)
+                yield Test(
+                    test, config=self.config, resultProxy=self.resultProxy
+                )
 
     _tests = property(_get_wrapped_tests, LazySuite._set_tests, None,
                       "Access the tests in this suite. Tests are returned "
@@ -357,11 +332,6 @@ class ContextSuite(LazySuite):
 
 
 class ContextSuiteFactory(object):
-    """Factory for ContextSuites. Called with a collection of tests,
-    the factory decides on a hierarchy of contexts by introspecting
-    the collection or the tests themselves to find the objects
-    containing the test objects. It always returns one suite, but that
-    suite may consist of a hierarchy of nested suites."""
     suiteClass = ContextSuite
 
     def __init__(self, config=None, suiteClass=None, resultProxy=_def):
@@ -370,8 +340,6 @@ class ContextSuiteFactory(object):
         self.config = config
         if suiteClass is not None:
             self.suiteClass = suiteClass
-        # Using a singleton to represent default instead of None allows
-        # passing resultProxy=None to turn proxying off.
         if resultProxy is _def:
             resultProxy = ResultProxyFactory(config=config)
         self.resultProxy = resultProxy
@@ -400,16 +368,11 @@ class ContextSuiteFactory(object):
         return self.makeSuite(tests, context, **kw)
 
     def ancestry(self, context):
-        """Return the ancestry of the context (that is, all of the
-        packages and modules containing the context), in order of
-        descent with the outermost ancestor last.
+        """This method returns the packages and modules containing the context.
         This method is a generator."""
         log.debug("get ancestry %s", context)
         if context is None:
             return
-        # Methods include reference to module they are defined in, we
-        # don't want that, instead want the module the class is in now
-        # (classes are re-ancestored elsewhere).
         if hasattr(context, 'im_class'):
             context = context.__self__.__class__
         elif hasattr(context, '__self__'):
@@ -427,13 +390,12 @@ class ContextSuiteFactory(object):
 
     def findContext(self, tests):
         if (
-            isinstance(tests, collections.Callable)
+            isinstance(tests, collections.abc.Callable)
             or isinstance(tests, unittest.TestSuite)
         ):
             return None
         context = None
         for test in tests:
-            # Don't look at suites for contexts, only tests
             ctx = getattr(test, 'context', None)
             if ctx is None:
                 continue
@@ -461,33 +423,19 @@ class ContextSuiteFactory(object):
         return suite
 
     def mixedSuites(self, tests):
-        """The complex case where there are tests that don't all share
-        the same context. Groups tests into suites with common ancestors,
-        according to the following (essentially tail-recursive) procedure:
-
-        Starting with the context of the first test, if it is not
-        None, look for tests in the remaining tests that share that
-        ancestor. If any are found, group into a suite with that
-        ancestor as the context, and replace the current suite with
-        that suite. Continue this process for each ancestor of the
-        first test, until all ancestors have been processed. At this
-        point if any tests remain, recurse with those tests as the
-        input, returning a list of the common suite (which may be the
-        suite or test we started with, if no common tests were found)
-        plus the results of recursion."""
         if not tests:
             return []
         head = tests.pop(0)
         if not tests:
-            return [head]  # short circuit when none are left to combine
-        suite = head  # the common ancestry suite, so far
+            return [head]
+        suite = head
         tail = tests[:]
         context = getattr(head, 'context', None)
         if context is not None:
             ancestors = [context] + [a for a in self.ancestry(context)]
             for ancestor in ancestors:
-                common = [suite]  # tests with ancestor in common, so far
-                remain = []  # tests that remain to be processed
+                common = [suite]
+                remain = []
                 for test in tail:
                     found_common = False
                     test_ctx = getattr(test, 'context', None)
@@ -512,7 +460,7 @@ class ContextSuiteFactory(object):
     def wrapTests(self, tests):
         log.debug("wrap %s", tests)
         if (
-            isinstance(tests, collections.Callable)
+            isinstance(tests, collections.abc.Callable)
             or isinstance(tests, unittest.TestSuite)
         ):
             log.debug("I won't wrap")
@@ -536,9 +484,6 @@ class ContextSuiteFactory(object):
 
 
 class ContextList(object):
-    """Not quite a suite -- a group of tests in a context. This is used
-    to hint the ContextSuiteFactory about what context the tests
-    belong to, in cases where it may be ambiguous or missing."""
     def __init__(self, tests, context=None):
         self.tests = tests
         self.context = context
@@ -548,10 +493,6 @@ class ContextList(object):
 
 
 class FinalizingSuiteWrapper(unittest.TestSuite):
-    """Wraps suite and calls final function after suite has
-    executed. Used to call final functions in cases (like running in
-    the standard test runner) where test running is not under nose's
-    control."""
     def __init__(self, suite, finalize):
         super(FinalizingSuiteWrapper, self).__init__()
         self.suite = suite
@@ -573,14 +514,14 @@ class FinalizingSuiteWrapper(unittest.TestSuite):
 class TestDir:
     def __init__(*arg, **kw):
         raise NotImplementedError(
-            "TestDir is not usable with nose 0.10. The class is present "
-            "in nose.suite for backwards compatibility purposes but it "
-            "may not be used.")
+            "TestDir is not usable. The class is present in nose.suite "
+            "for backwards compatibility purposes but it may not be used."
+        )
 
 
 class TestModule:
     def __init__(*arg, **kw):
         raise NotImplementedError(
-            "TestModule is not usable with nose 0.10. The class is present "
-            "in nose.suite for backwards compatibility purposes but it "
-            "may not be used.")
+            "TestModule is not usable. The class is present in nose.suite "
+            "for backwards compatibility purposes but it may not be used."
+        )
