@@ -80,8 +80,6 @@ def _ls_tree_lines(dir_path, skip_pattern,
 
 
 def absdir(path):
-    """Return absolute, normalized path to directory, if it exists; None
-    otherwise."""
     if not os.path.isabs(path):
         path = os.path.normpath(
             os.path.abspath(os.path.join(os.getcwd(), path))
@@ -92,9 +90,6 @@ def absdir(path):
 
 
 def absfile(path, where=None):
-    """Return absolute, normalized path to file (optionally in directory
-    where), or None if the file can't be found either in where or the current
-    working directory."""
     orig = path
     if where is None:
         where = os.getcwd()
@@ -108,13 +103,12 @@ def absfile(path, where=None):
         path = os.path.normpath(os.path.abspath(os.path.join(where, path)))
     if path is None or not os.path.exists(path):
         if where != os.getcwd():
-            # try the cwd instead
-            path = os.path.normpath(os.path.abspath(os.path.join(os.getcwd(),
-                                                                 orig)))
+            path = os.path.normpath(
+                os.path.abspath(os.path.join(os.getcwd(), orig))
+            )
     if path is None or not os.path.exists(path):
         return None
     if os.path.isdir(path):
-        # might want an __init__.py from pacakge
         init = os.path.join(path, '__init__.py')
         if os.path.isfile(init):
             return init
@@ -153,8 +147,6 @@ def func_lineno(func):
 
 
 def isclass(obj):
-    """Is obj a class? Inspect's isclass is too liberal and returns True
-    for objects that can't be subclasses of anything."""
     obj_type = type(obj)
     return obj_type in class_types or issubclass(obj_type, type)
 
@@ -283,7 +275,6 @@ def ln(label):
 def resolve_name(name, module=None):
     """Resolve a dotted name to a module and its parts. This is stolen
     wholesale from unittest.TestLoader.loadTestByName.
-
     >>> resolve_name('nose.util') #doctest: +ELLIPSIS
     <module 'nose.util' from...>
     >>> resolve_name('nose.util.resolve_name') #doctest: +ELLIPSIS
@@ -311,48 +302,33 @@ def resolve_name(name, module=None):
 def split_test_name(test):
     """Split a test name into a 3-tuple containing file, module, and callable
     names, any of which (but not all) may be blank.
-
     Test names are in the form:
-
     file_or_module:callable
-
     Either side of the : may be dotted. To change the splitting behavior, you
     can alter nose.util.split_test_re."""
     norm = os.path.normpath
     file_or_mod = test
     fn = None
     if ':' not in test:
-        # only a file or mod part
         if file_like(test):
             return (norm(test), None, None)
         else:
             return (None, test, None)
-
-    # could be path|mod:callable, or a : in the file path someplace
     head, tail = os.path.split(test)
     if not head:
-        # this is a case like 'foo:bar' -- generally a module
-        # name followed by a callable, but also may be a windows
-        # drive letter followed by a path
         try:
             file_or_mod, fn = test.split(':')
             if file_like(fn):
-                # must be a funny path
                 file_or_mod, fn = test, None
         except ValueError:
-            # more than one : in the test
-            # this is a case like c:\some\path.py:a_test
             parts = test.split(':')
             if len(parts[0]) == 1:
                 file_or_mod, fn = ':'.join(parts[:-1]), parts[-1]
             else:
-                # nonsense like foo:bar:baz
                 raise ValueError("Test name '%s' could not be parsed. Please "
                                  "format test names as path:callable or "
                                  "module:callable." % (test,))
     elif not tail:
-        # this is a case like 'foo:bar/'
-        # : must be part of the file path, so ignore it
         file_or_mod = test
     else:
         if ':' in tail:
@@ -377,8 +353,6 @@ def test_address(test):
     class, method or function."""
     if hasattr(test, "address"):
         return test.address()
-    # type-based polymorphism sucks in general, but I believe is
-    # appropriate here
     t = type(test)
     file = module = call = None
     if t == types.ModuleType:  # noqa: E721
@@ -414,7 +388,6 @@ def test_address(test):
                 return test_address(test._testFunc)
         # regular unittest.TestCase
         cls_adr = test_address(test.__class__)
-        # 2.5 compat: __testMethodName changed to _testMethodName
         try:
             method_name = test._TestCase__testMethodName
         except AttributeError:
@@ -481,7 +454,6 @@ def src(filename):
 def regex_last_key(regex):
     """Sort key function factory that puts items that match a
     regular expression last.
-
     >>> from nose.config import Config
     >>> from nose.pyversion import sort_list
     >>> c = Config()
@@ -500,27 +472,22 @@ def regex_last_key(regex):
 def tolist(val):
     """Convert a value that may be a list or a (possibly comma-separated)
     string into a list. The exception: None is returned as None, not [None].
-
     >>> tolist(["one", "two"])
     ['one', 'two']
     >>> tolist("hello")
     ['hello']
     >>> tolist("separate,values, with, commas,  spaces , are    ,ok")
-    ['separate', 'values', 'with', 'commas', 'spaces', 'are', 'ok']
-    """
+    ['separate', 'values', 'with', 'commas', 'spaces', 'are', 'ok'] """
     if val is None:
         return None
     try:
-        # might already be a list
         val.extend([])
         return val
     except AttributeError:
         pass
-    # might be a string
     try:
         return re.split(r'\s*,\s*', val)
     except TypeError:
-        # who knows...
         return list(val)
 
 
@@ -577,10 +544,8 @@ class odict(dict):
 
 
 def transplant_func(func, module):
-    """
-    Make a function imported from module A appear as if it is located
+    """Make a function imported from module A appear as if it is located
     in module B.
-
     >>> from pprint import pprint
     >>> pprint.__module__
     'pprint'
@@ -589,12 +554,10 @@ def transplant_func(func, module):
     'nose.util'
 
     The original function is not modified.
-
     >>> pprint.__module__
     'pprint'
 
     Calling the transplanted function calls the original.
-
     >>> pp([1, 2])
     [1, 2]
     >>> pprint([1,2])
@@ -615,10 +578,8 @@ def transplant_func(func, module):
 
 
 def transplant_class(cls, module):
-    """
-    Make a class appear to reside in `module`, rather than the module in which
-    it is actually defined.
-
+    """Make a class appear to reside in `module`,
+    rather than the module in which it is actually defined.
     >>> from nose.failure import Failure
     >>> Failure.__module__
     'nose.failure'
@@ -627,7 +588,6 @@ def transplant_class(cls, module):
     'nose.util'
     >>> Nf.__name__
     'Failure' """
-
     class C(cls):
         pass
 
